<?php
/*
 * Plugin Name: WooCommerce TygaPay PayMe
 * Plugin URI: https://tygapay.com
 * Description: Pay using your crytocurrency
 * Author: TygaPay
 * Author URI: https://tygapay.com
 * Version: 1.0.4
 */

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * WC Payment gateway plugin class.
 *
 * @class WC_PayMe_Payments
 */
class WC_PayMe_Payments {

	/**
	 * Plugin bootstrapping.
	 */
	public static function init() {

		// Payments gateway class.
		add_action( 'plugins_loaded', array( __CLASS__, 'includes' ), 0 );

    add_filter('http_request_timeout', 'wp9838c_timeout_extend');
    function wp9838c_timeout_extend($time) {
        return 10;
    }

		// Make the Payments gateway available to WC.
		add_filter( 'woocommerce_payment_gateways', array( __CLASS__, 'payme_gateway' ) );

		// Registers WooCommerce Blocks integration.
		add_action( 'woocommerce_blocks_loaded', array( __CLASS__, 'woocommerce_gateway_payme_woocommerce_block_support' ) );

	}

	/**
	 * Add the Payment gateway to the list of available gateways.
	 *
	 * @param array
	 */
	public static function payme_gateway( $gateways ) {
    $gateways[] = 'WC_Gateway_PayMe';
		return $gateways;
	}

	/**
	 * Plugin includes.
	 */
	public static function includes() {

		// Make the WC_Gateway_PayMe class available.
		if ( class_exists( 'WC_Payment_Gateway' ) ) {
			require_once 'includes/class-wc-gateway-payme.php';
		}
	}

	/**
	 * Plugin url.
	 *
	 * @return string
	 */
	public static function plugin_url() {
		return untrailingslashit( plugins_url( '/', __FILE__ ) );
	}

	/**
	 * Plugin url.
	 *
	 * @return string
	 */
	public static function plugin_abspath() {
		return trailingslashit( plugin_dir_path( __FILE__ ) );
	}

	/**
	 * Registers WooCommerce Blocks integration.
	 *
	 */
	public static function woocommerce_gateway_payme_woocommerce_block_support() {
		if ( class_exists( 'Automattic\WooCommerce\Blocks\Payments\Integrations\AbstractPaymentMethodType' ) ) {
			require_once 'includes/blocks/class-wc-payme-payments-blocks.php';
			add_action(
				'woocommerce_blocks_payment_method_type_registration',
				function( Automattic\WooCommerce\Blocks\Payments\PaymentMethodRegistry $payment_method_registry ) {
					$payment_method_registry->register( new WC_Gateway_PayMe_Blocks_Support() );
				}
			);
		}
	}
}

WC_PayMe_Payments::init();
